from fastapi import APIRouter, HTTPException, status
from schemas.contact_form import ContactFormCreate
from helpers.contact_form_helpers import create_contact_form, validate_email
from sqlalchemy.orm import Session
from fastapi import Depends
from core.database import get_db

router = APIRouter()

@router.post("/contact", status_code=status.HTTP_201_CREATED, response_model=ContactFormCreate)
async def create_contact(contact_form: ContactFormCreate, db: Session = Depends(get_db)):
    if not contact_form.name:
        raise HTTPException(status_code=400, detail="Name is required")
    if not contact_form.email:
        raise HTTPException(status_code=400, detail="Email is required")
    if not validate_email(contact_form.email):
        raise HTTPException(status_code=400, detail="Invalid email format")
    if not contact_form.message:
        raise HTTPException(status_code=400, detail="Message is required")

    new_contact_form = create_contact_form(db=db, contact_form_data=contact_form)
    return new_contact_form